==> elemental2-dom-1.2.3.jar: elemental2/dom/TrustedTypePolicyFactory.java <==
/*
 * Copyright 2018 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package elemental2.dom;

import elemental2.core.TrustedScript;
import jsinterop.annotations.JsPackage;
import jsinterop.annotations.JsType;

@JsType(isNative = true, namespace = JsPackage.GLOBAL)
public class TrustedTypePolicyFactory {
  public TrustedTypePolicy defaultPolicy;
  public TrustedHTML emptyHTML;
  public TrustedScript emptyScript;

  public native TrustedTypePolicy createPolicy(String name, TrustedTypePolicyOptions policy);

  public native String getAttributeType(
      String tagName, String attribute, String elementNs, String attrNs);

  public native String getAttributeType(String tagName, String attribute, String elementNs);

  public native String getAttributeType(String tagName, String attribute);

  public native String getPropertyType(String tagName, String property, String elementNs);

  public native String getPropertyType(String tagName, String property);

  public native boolean isHTML(Object obj);

  public native boolean isScript(Object obj);

  public native boolean isScriptURL(Object obj);
}

==> elemental2-dom-1.3.2.jar: elemental2/dom/TrustedTypePolicyFactory.java <==
/*
 * Copyright 2018 Google Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package elemental2.dom;

import elemental2.core.TrustedScript;
import jsinterop.annotations.JsPackage;
import jsinterop.annotations.JsType;
import org.jspecify.annotations.Nullable;

@JsType(isNative = true, namespace = JsPackage.GLOBAL)
public class TrustedTypePolicyFactory {
  public @Nullable TrustedTypePolicy defaultPolicy;
  public TrustedHTML emptyHTML;
  public TrustedScript emptyScript;

  public native TrustedTypePolicy createPolicy(String name, TrustedTypePolicyOptions policy);

  public native @Nullable String getAttributeType(
      String tagName, String attribute, String elementNs, String attrNs);

  public native @Nullable String getAttributeType(
      String tagName, String attribute, String elementNs);

  public native @Nullable String getAttributeType(String tagName, String attribute);

  public native @Nullable String getPropertyType(String tagName, String property, String elementNs);

  public native @Nullable String getPropertyType(String tagName, String property);

  public native boolean isHTML(@Nullable Object obj);

  public native boolean isScript(@Nullable Object obj);

  public native boolean isScriptURL(@Nullable Object obj);
}
